import React, { useCallback, useState } from 'react';
import { LogoutOutlined, SettingOutlined, UserOutlined } from '@ant-design/icons';
import { Avatar, Menu, Spin, message } from 'antd';
import { history, useModel } from 'umi';
import { stringify } from 'querystring';
import HeaderDropdown from '../HeaderDropdown';
import UpPwdForm from './components/UpPwdForm';
import styles from './index.less';
import api from '@/services/api';

/**
 * 退出登录，并且将当前的 url 保存
 */
const loginOut = async () => {
  await api.outLogin();
  const { query = {}, pathname } = history.location;
  const { redirect } = query;

  if (window.location.pathname !== '/user/login' && !redirect) {
    history.replace({
      pathname: '/user/login',
      search: stringify({
        redirect: pathname,
      }),
    });
  }
};

const AvatarDropdown = ({ menu }) => {
  const { initialState, setInitialState } = useModel('@@initialState');
  const [pwdIsOpen, setPwdIsOpen] = useState(false);
  const [stepFormValues, setStepFormValues] = useState({});
  const onMenuClick = useCallback(
    (event) => {
      const { key } = event;
      if (key === 'logout' && initialState) {
        setInitialState({ ...initialState, currentUser: undefined });
        loginOut();
        return;
      }
      if(key === 'upPwd'){
        api.queryCurrent().then((r)=>{
          setStepFormValues(r.data);
          setPwdIsOpen(true);
        })
        return;
      }
      history.push(`/account/${key}`);
    },
    [initialState, setInitialState],
  );
  const loading = (
    <span className={`${styles.action} ${styles.account}`}>
      <Spin
        size="small"
        style={{
          marginLeft: 8,
          marginRight: 8,
        }}
      />
    </span>
  );

  if (!initialState) {
    return loading;
  }

  const { currentUser } = initialState;

  if (!currentUser || !currentUser.succeeded) {
    return loading;
  }

  const menuHeaderDropdown = (
    <Menu className={styles.menu} selectedKeys={[]} onClick={onMenuClick}>
      {menu && (
        <Menu.Item key="center">
          <UserOutlined />
          个人中心1
        </Menu.Item>
      )}
      {menu && (
        <Menu.Item key="settings">
          <SettingOutlined />
          个人设置
        </Menu.Item>
      )}
      {menu && <Menu.Divider />}
      <Menu.Item key="upPwd">
        <UserOutlined />
        修改密码
      </Menu.Item>
      <Menu.Item key="logout">
        <LogoutOutlined />
        退出登录
      </Menu.Item>
    </Menu>
  );
  return (
    <>
    <HeaderDropdown overlay={menuHeaderDropdown}>
      <span className={`${styles.action} ${styles.account}`}>
        <Avatar size="small" className={styles.avatar}  gap='4' alt="avatar" >{currentUser.data.name}</Avatar>
        <span className={`${styles.name} anticon`}>{currentUser.data.name}</span>
      </span>
    </HeaderDropdown>

    <UpPwdForm
        onFinish={async (value) => {
          await api.UpdatePwd(value).then(r => {
            if(r.data){
              message.success("修改成功")
              setPwdIsOpen(false);
              loginOut();
            }else{
              message.error(r.errors);
            }
          })
        }}
        onCancel={() => {
          setPwdIsOpen(false);
        }}
        values={stepFormValues || {}}
        pwdIsOpen={pwdIsOpen}
      />
    </>
  );
};

export default AvatarDropdown;
