import { PlusOutlined } from '@ant-design/icons';
import { Modal, Col, Row, Button, Divider, Space, Input, message } from 'antd';
import { useState, useEffect, useRef } from 'react';
import ProForm, { ProFormSelect, ProFormText } from '@ant-design/pro-form';
import api from '../service'
const fieldLabels = {
  name: '物料名称',
  stockUint: '物料单位',
  specs: '物料规格',
  code: '物料编码',
  aittribute: '物料属性',
  typeID: '物料分类',
  status: '物料状态',
  price: '成本价',
  netrecovery: '净料率(%)',
  OutstockUint: '出库单位',
  proportion: '换算比例(%)',
  foreignKeyRe: '关联外键'
};

const CreateForm = (props) => {
  const { modalVisible, onCancel } = props;
  const formRef = useRef();
  const [items, setItems] = useState([]);
  const [itemsuity, setitemsuity] = useState([]);
  const [name, setName] = useState('');
  const [uityname, setuityname] = useState('');
  const inputRef = useRef(null);
  const inputuityRef = useRef(null);
  const getTableInfo = () => {
  };
  useEffect(() => {
    getTableInfo();
    setItems(props.typeListData)
    setitemsuity(props.uintListData)
  }, [modalVisible]);

  const onNameChange = (event) => {
    setName(event.target.value);
  };
  const onNameuityChange = (event) => {
    setuityname(event.target.value)
  }
  const addItem = (e) => {
    e.preventDefault();
    if (name.length == 0) {
      message.error("请输入名称");
    } else {
      var parm = { name: name }
      api.addbatchingtype(parm).then((res) => {
        if (res.succeeded) {
          message.success('添加成功');
          props.initTypeList();
          setName('');
        } else {
          message.error(res.errors);
        }
      })
    }

  };
  const addItemuity = (e) => {
    e.preventDefault();

    if (uityname.length == 0) {
      message.error("请输入名称");
    } else {
      var parm = { name: uityname }
      api.addbatchinguint(parm).then((res) => {
        if (res.succeeded) {
          props.initUintList()
          setuityname('');
          message.success('添加成功');
        } else {
          message.error(res.errors);
        }
      })
    }
  };
  return (
    <Modal
      destroyOnClose
      title={props.values.id ? '编辑物料' : '新建物料'}
      width={1000}
      open={modalVisible}
      onCancel={() => onCancel()}
      footer={null}
      maskClosable={false}
    >
      <ProForm
        layout="horizontal"
        formRef={formRef}
        initialValues={props.values}
        onFinish={props.onFinish}
        submitter={false}
      >
        <Row gutter={16}>
          <Col lg={12} md={12} sm={24}>
            <ProFormText
              label={fieldLabels.code}
              disabled={true}
              name="code"
              rules={[
                {
                  required: true,
                  max: 50,
                },
              ]}
              placeholder="请输入原料编码"
            />
          </Col>
          <Col lg={12} md={12} sm={24}>
            <ProFormText name="id" hidden={true} />
            <ProFormText
              label={fieldLabels.name}
              name="name"
              rules={[
                {
                  required: true,
                  max: 50,
                },
              ]}
              placeholder="请输入原料名称"
            />
          </Col>
        </Row>

        <Row gutter={16}>
          <Col lg={12} md={12} sm={24}>
            <ProFormSelect
              label={fieldLabels.typeID}
              name="typeID"
              style={{ width: '100%', }}
              showSearch
              rules={[
                {
                  required: true,
                  message: '请选择物料分类',
                },
              ]}
              placeholder="请选择物料分类"
              fieldProps={{
                dropdownRender: (menu) => (
                  <>
                    {menu}
                    <Divider
                      style={{
                        margin: '8px 0',
                      }}
                    />
                    <Space
                      style={{
                        padding: '0 8px 4px',
                      }}
                    >
                      <Input
                        placeholder="请输入物料分类"
                        ref={inputRef}
                        value={name}
                        onChange={onNameChange}
                        onKeyDown={(e) => e.stopPropagation()}
                      />
                      <Button type="text" icon={<PlusOutlined />} onClick={addItem}>
                        添加
                      </Button>
                    </Space>
                  </>
                )
              }}
              options={items}
            />
          </Col>
          <Col lg={12} md={12} sm={24}>

            <ProFormSelect
              label={fieldLabels.stockUint}
              name="stockUint"
              showSearch
              rules={[
                {
                  required: true,
                  message: '请选择单位',
                },
              ]}
              style={{ width: '100%', }}
              placeholder="请选择物料单位"
              fieldProps={{
                dropdownRender: (menu) => (
                  <>
                    {menu}
                    <Divider
                      style={{
                        margin: '8px 0',
                      }}
                    />
                    <Space
                      style={{
                        padding: '0 8px 4px',
                      }}
                    >
                      <Input
                        placeholder="请输入物料单位"
                        ref={inputuityRef}
                        value={uityname}
                        onChange={onNameuityChange}
                        onKeyDown={(e) => e.stopPropagation()}
                      />
                      <Button type="text" icon={<PlusOutlined />} onClick={addItemuity}>
                        添加
                      </Button>
                    </Space>
                  </>
                )
              }}
              options={itemsuity}
            />
          </Col>
        </Row>
        <Row gutter={4}>
          <Col span={12}></Col>
          <Col span={12}>
            <Button htmlType="button" style={{ float: 'right', left: 10 }} onClick={onCancel} >取消</Button>
            <Button disabled={!props.codeList.includes('BatchingUp')} type="primary" htmlType="submit" style={{ float: 'right' }} >保存</Button>
          </Col>
        </Row>
      </ProForm>
    </Modal>
  );
};

export default CreateForm;
