import { Button, message, Popconfirm, Modal, Transfer } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import CreateForm from './components/CreateForm';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { getGoodsClassifyPage, updateGoodsClassify, deleteGoodsClassify, getgoodslist, getRelation, setRelation } from './service';
import publicApi from '@/services/api';

const GoodsClassify = () => {
    const [goodsClassifyVisible, setGoodsClassifyVisible] = useState(false);
    const actionRef = useRef();
    const [currentRow, setCurrentRow] = useState();
    const [selectedRowsState, setSelectedRows] = useState([]);
    const [targetKeys, setTargetKeys] = useState([]);
    const [isModalOpen, setIsModalOpen] = useState(false);
    const [mockData, setMockData] = useState([]);
    const [classifyId, setClassifyId] = useState([]);
    const [codeList, setCodeList] = useState([]);
    useEffect(() => {
        publicApi.getRoleBasicMenu().then((r) => {
            if (r.data) {
                setCodeList(r.data)
            }
        })
        getgoodslist().then((item) => {
            var data = item.data;
            const tempMockData = [];
            data.forEach((item) => {
                tempMockData.push({
                    key: item.id,
                    title: item.name,
                    description: item.name,
                });
            })
            setMockData(tempMockData);
        });

    }, []);
    /**
    * 添加节点
    *
    * @param fields
    */
    const handleAdd = async (fields) => {
        return await updateGoodsClassify(JSON.stringify(fields)).then((r) => {
            if (r.data) {
                message.success('添加成功');
                return true;
            } else {
                message.error(r.errors);
                return false;
            }
        })
    };

    /**
    * 更新节点去
    *
    * @param fields
    */
    const handleUpdate = async (fields) => {
        return await updateGoodsClassify(JSON.stringify(fields)).then((r) => {
            if (r.data) {
                message.success('修改成功');
                return true;
            } else {
                message.error(r.errors);
                return false;
            }
        })
    };
    const BatchDeletion = () => {
        return (
            selectedRowsState?.length > 0 &&
            (
                <Popconfirm
                    title="确认删除吗?"
                    onConfirm={onClickdele}
                    okText="确定"
                    cancelText="取消"
                >
                    <Button type="primary">批量删除</Button>
                </Popconfirm>
            ))
    }
    const onClickdele = () => {
        handleRemove(selectedRowsState);
        setSelectedRows([]);
        actionRef.current?.reloadAndRest?.();
    }
    /**
    * 批量删除
    *
    * @param selectedRows
    */
    const handleRemove = async (selectedRows) => {
        if (!selectedRows) return true;
        await deleteGoodsClassify(selectedRows.map((row) => row.id)).then((r) => {
            if (r.succeeded) {
                message.success('删除成功');
                actionRef.current.reload();
            } else {
                message.error(r.errors);
            }
        });
        return true;
    };

    const editGoodsClassify = async () => {
        const tempMockData = [];
        targetKeys.forEach(function (item, index, array) {
            tempMockData.push({
                "goodsId": item
            });
        })
        var data = {
            "classifyId": classifyId,
            "goodsIdList": tempMockData
        }
        setRelation(data).then((r) => {
            console.log(r);
            if (r.succeeded) {
                message.success('编辑成功');
            } else {
                message.error(r.errors)
            }
        });
        setIsModalOpen(false);
        actionRef.current.reload();
    };

    const getGoodsList = async (classifyId) => {
        var list = [];
        getRelation(classifyId).then((item) => {
            item.data.forEach(function (item) {
                list.push(item.goodsId);
            })
            setTargetKeys(list);
        });
    };

    const handleChange = (newTargetKeys) => {
        setTargetKeys(newTargetKeys);
    };

    const columns = [
        {
            title: '主键',
            dataIndex: 'id',
            hideInSearch: true,
            hideInTable: true,
            tip: '规则名称是唯一的 key',
            render: (dom, entity) => {
                return (
                    <a
                        onClick={() => {
                            setCurrentRow(entity);
                        }}
                    >
                        {dom}
                    </a>
                );
            },
        },
        {
            title: '名称',
            dataIndex: 'name',
            valueType: 'textarea',
            ellipsis: true,
        },

        {
            title: '备注',
            dataIndex: 'remark',
            ellipsis: true,
            hideInForm: true,
            hideInSearch: true,
        },
        {
            title: '排序',
            dataIndex: 'sort',
            hideInSearch: true,
        },
        {
            title: '操作',
            dataIndex: 'option',
            valueType: 'option',
            render: (_, record) => [
                <a
                    key="config"
                    onClick={() => {
                        setGoodsClassifyVisible(true);
                        setCurrentRow(record);
                    }}
                >
                    更新
                </a>,
                codeList.includes('GoodClassifyDel') && (
                    <Popconfirm
                        type="primary"
                        key="primary"
                        title="确认删除吗？"
                        okText="是"
                        cancelText="否"
                        onConfirm={async () => {
                            await deleteGoodsClassify(record.id).then((r) => {
                                if (r.succeeded) {
                                    message.success('删除成功');
                                    actionRef.current.reload();
                                } else {
                                    message.error(r.errors);
                                }
                            });
                        }}
                        onCancel={() => { }}
                    >
                        <a href="#">删除</a>
                    </Popconfirm>),
                <a
                    key="edit"
                    onClick={() => {
                        getGoodsList(record.id);
                        setClassifyId(record.id);
                        setIsModalOpen(true);
                    }}
                >
                    设置商品
                </a>,
            ],
        },
    ];

    return (
        <PageContainer host header={{
            title: '',
            breadcrumb: {},
        }}>
            <ProTable
                headerTitle=""
                actionRef={actionRef}
                rowKey="id"
                pagination={{ defaultPageSize: 10 }}
                search={{
                    labelWidth: 120,
                }}
                toolBarRender={() => [
                    codeList.includes('GoodClassifyAdd') && (
                        <Button
                            type="primary"
                            key="primary"
                            onClick={() => {
                                setGoodsClassifyVisible(true);
                            }}
                        >
                            <PlusOutlined /> 新建
                        </Button>),
                    codeList.includes('GoodClassifyDel') && (
                        <BatchDeletion />),
                ]}
                request={async (params) => {
                    var goodsClassifyData = [];
                    var total = 0;
                    await getGoodsClassifyPage(params).then((r) => {
                        goodsClassifyData = r.data.data;
                        total = r.data.total;
                    });
                    return {
                        data: goodsClassifyData,
                        success: true,
                        total: total
                    };
                }}
                columns={columns}
                rowSelection={{
                    onChange: (_, selectedRows) => {
                        setSelectedRows(selectedRows);
                    }
                }}
            />
            <CreateForm
                key={Date.now()}
                onFinish={async (value) => {
                    var success = false;
                    if (value.id) {
                        success = await handleUpdate(value);
                    } else {
                        success = await handleAdd(value);
                    }
                    if (success) {
                        setGoodsClassifyVisible(false);
                        setCurrentRow(undefined);
                        actionRef.current.reload();
                    }
                }}
                onCancel={() => {
                    setGoodsClassifyVisible(false);
                    setCurrentRow(undefined);
                }}
                codeList={codeList}
                goodsClassifyVisible={goodsClassifyVisible}
                values={currentRow || {}}
            />
            <Modal
                width={790}
                title="设置商品"
                open={isModalOpen}
                destroyOnClose
                onOk={() => { editGoodsClassify() }}
                onCancel={() => { setIsModalOpen(false) }}
                footer={
                    [
                        <Button type="default" onClick={() => setIsModalOpen(false)}>
                            取消
                        </Button>,
                        <Button disabled={!codeList.includes('GoodClassifySet')} type="primary" onClick={editGoodsClassify}>
                            确定
                        </Button>
                    ]
                }
            >
                <Transfer
                    className="tree-transfer"
                    listStyle={{
                        width: 350,
                        height: 400,
                    }}
                    dataSource={mockData}
                    targetKeys={targetKeys}
                    onChange={handleChange}
                    showSearch
                    showSelectAll
                    render={(item) => item.title}
                />
            </Modal>
        </PageContainer>
    );
}
export default GoodsClassify;