import { PlusOutlined } from '@ant-design/icons';
import { Button, message, Drawer, Popconfirm,Modal } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import ProDescriptions from '@ant-design/pro-descriptions';
import CreateForm from './components/CreateForm';
import GoodsAttribute from './components/CreateGoodsAttribute';
import { goodsType, addGoodsType, gettree, DeleteGoodsType } from './service';
import publicApi from '@/services/api';

const GoodsTypeManage = () => {
  /** 新建/更新窗口的弹窗 */
  const [createformModalVisible, handleModalVisible] = useState(false);
  /** 分布更新窗口的弹窗 */
  const [showDetail, setShowDetail] = useState(false);
  const actionRef = useRef();
  const [currentRow, setCurrentRow] = useState();
  const [selectedRowsState, setSelectedRows] = useState([]);
  const [treeData, setTreeData] = useState();
  const [GoodsAttributeVisible,setGoodsAttributeVisible]= useState(false);
  const [codeList, setCodeList] = useState([]);
  /** 国际化修改 */
  useEffect(() => {
    publicApi.getRoleBasicMenu().then((r) => {
      if (r.data) {
        setCodeList(r.data)
      }
    })
    intDicData();
  }, []);
  function intDicData() {
    gettree().then((r) => {
      setTreeData(r.data);
    });
  }

  /**
 * 添加节点
 *
 * @param fields
 */
  const handleAdd = async (fields) => {
    return await addGoodsType(JSON.stringify(fields)).then((r) => {
      if (r.succeeded) {
        message.success('添加成功');
        intDicData();
        return true;
      } else {
        message.error(r.errors);
        return false;
      }
    });
  };
/**
 * 更新节点去
 *
 * @param fields
 */

  const handleUpdate = async (fields) => {
    return await addGoodsType(JSON.stringify(fields)).then((r) => {
      if (r.succeeded) {
        message.success('修改成功');
        intDicData();
        return true;
      } else {
        message.error(r.errors);
        return false;
      }
    });
  };
  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  /**
   * 批量删除
   *
   * @param selectedRows
   */
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await DeleteGoodsType(selectedRows.map((row) => row.id)).then((r) => {
      if (r.succeeded) {
        message.success('删除成功');
        actionRef.current.reload();
        intDicData()
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };
  const onGoodsAttributeCancel=()=>{
    setGoodsAttributeVisible(false);
    setCurrentRow({});
  }
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key',
      render: (dom, entity) => {
        return (
          <a
            onClick={() => {
              setCurrentRow(entity);
              setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
    },
    {
      title: '名称',
      dataIndex: 'name',
      valueType: 'textarea',
      ellipsis: true,
    },

    {
      title: '备注',
      dataIndex: 'remark',
      ellipsis: true,
      hideInForm: true,
      hideInSearch: true,
    },
    {
      title: '排序',
      dataIndex: 'sort',
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <a
          key="config"
          onClick={() => {
            if (record.pid == "0") {
              record.pid = null;
            }
            setGoodsAttributeVisible(true);
            setCurrentRow(record);
          }}
        >
          更新
        </a>,
        codeList.includes('GoodTypeDel') && (
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={async () => {
            await DeleteGoodsType(record.id).then((r) => {
              if (r.succeeded) {
                message.success('删除成功');
                actionRef.current.reload();
              } else {
                message.error(r.errors);
              }
            });
          }}
          onCancel={() => {}}
        >
          <a href="#">删除</a>
        </Popconfirm>),
      ],
    },
  ];

  return (
    <PageContainer host header={{
      title: '',
      breadcrumb: {},
    }}>
      <ProTable
        headerTitle=""
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          codeList.includes('GoodTypeAdd') && (
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setGoodsAttributeVisible(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>),
          codeList.includes('GoodTypeDel') && (
          <BatchDeletion />),
        ]}
        request={async (params) => {
          var goodsData = [];
          var total = 0;
          await goodsType(params).then((r) => {
            goodsData = r.data.data;
            goodsData.forEach((x) => {
              x.status = x.status.toString();
            });
            total = r.data.total;
          });
          return {
            data: goodsData,
            success: true,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          }
        }}
      />
      <CreateForm
        key={Date.now()}
        treeDatas={treeData}
        onFinish={async (value) => {
          var success = false;
          if (value.id) {
            success = await handleUpdate(value);
          } else {
            success = await handleAdd(value);
          }
          if (success) {
            handleModalVisible(false);
            setCurrentRow(undefined);
            if (actionRef.current) {
              actionRef.current.reload();
            }
          }
        }}
        onCancel={() => {
          handleModalVisible(false);
          setCurrentRow(undefined);
        }}
        createformModalVisible={createformModalVisible}
        values={currentRow || {}}
      />
      <Modal
        key={Date.now()}
        title={currentRow?.name ? '更新' : '新建'}
        width={700}
        open={GoodsAttributeVisible}
        bodyStyle={{ padding: '32px 40px 1px 48px' }}
        footer={null}
        onCancel={() => {
          onGoodsAttributeCancel();
        }}
        destroyOnClose={true}>
        <GoodsAttribute
          onFinish={async (value) => {
            var success = false;
            if (value.id) {
              success = await handleUpdate(value);
            } else {
              success = await handleAdd(value);
            }
            if (success) {
              setGoodsAttributeVisible(false);
              setCurrentRow(undefined);
              actionRef.current.reload();
            }
          }}
          onCancel={() => {
            setGoodsAttributeVisible(false);
            setCurrentRow(undefined);
          }}
          codeList={codeList}
          values={currentRow}
          treeDatas={treeData}
        />
      </Modal>

      <Drawer
        width={600}
        visible={showDetail}
        onClose={() => {
          setCurrentRow(undefined);
          setShowDetail(false);
        }}
        closable={false}
      >
        {currentRow?.name && (
          <ProDescriptions
            column={2}
            title={currentRow?.name}
            request={async () => ({
              data: currentRow || {},
            })}
            params={{
              id: currentRow?.name,
            }}
            columns={columns}
          />
        )}
      </Drawer>
    </PageContainer>
  );
};

export default GoodsTypeManage;
