import { PlusOutlined, UploadOutlined, DeleteOutlined } from '@ant-design/icons';
import React, { useRef, useState, useEffect } from 'react';
import { message, Modal, Form, Input, Button, Upload, Select, InputNumber, TreeSelect, Switch, Divider, Space } from 'antd';
import { GetAliyunRequestURL, getgoodstypetree, unitList, addunit } from '../service';
const { TextArea } = Input;
const CreateForm = (props) => {
    const [treeData, setTreeData] = useState();
    const [goodsUnit, setGoodsUnit] = useState([]);
    const [goodsTypeIdvalue, setgoodsTypeIdvalue] = useState();
    const inputRef = useRef();
    const [unitname, setunitname] = useState('');
    const [url, setUrl] = useState(null);
    const [hovered, setHovered] = useState(false);
    const [imageError, setImageError] = useState(false);
    useEffect(() => {
        initGoodsUnit();
        initGoodsType();
        props.form.setFieldsValue(props.values);
        setUrl(props.values.imgUrl);
    }, [props.values])
    function initGoodsUnit() {
        unitList().then((r) => {
            var list = [];
            if (r.data.length > 0) {
                r.data.forEach((item) => {
                    list.push({ text: item.name, value: item.id, label: item.name });
                });
            }
            setGoodsUnit(list);
        });
    }
    function initGoodsType() {
        getgoodstypetree().then((r) => {
            setTreeData(r.data);
        });
    }
    const onNameChange = (event) => {
        setunitname(event.target.value);
    };
    const addItem = (e) => {
        e.preventDefault();
        if (unitname.length == 0) {
            message.error("请输入名称");
        } else {
            var parm = { name: unitname }
            addunit(parm).then((r) => {
                if (r.succeeded) {
                    message.success('添加成功');
                    initGoodsUnit();
                    setunitname('');
                } else {
                    message.error(r.errors);
                }
            })
        }
    };
    const onChange = (newValue) => {
        setgoodsTypeIdvalue(newValue);
    };
    const filterOption = (input, option) =>
        (option?.title ?? '').toLowerCase().includes(input.toLowerCase());
    const uploadProp = {
        customRequest({
            file,
        }) {
            GetAliyunRequestURL({ directory: "hkerp/test/goods", buildUniqueDirectory: false }).then((res) => {
                if (res.success_Action_Status == 200) {
                    var formData = new FormData(); //注意formData里append添加的键的大小写
                    formData.append("name", file.name); //文件名
                    formData.append("key", res.key); //存储在oss的文件路径
                    formData.append("ossAccessKeyId", res.ossAccessKeyId); //accessKeyId
                    formData.append("policy", res.policy); //policy
                    formData.append("signature", res.signature); //签名 //如果是base64文件，那么直接把base64字符串转成blob对象进行上传就可以了
                    formData.append("file", file);
                    formData.append("success_Action_Status", 200); //成功后返回的操作码
                    formData.append("host", res.host);
                    fetch(res.host, {
                        method: "POST",
                        body: formData,
                    }).then((response) => {
                        if (response.ok) {
                            setUrl(`${res.host}/${res.key.replace("${filename}", file.name)}`)
                            setImageError(false)
                        }
                    }).catch((error) => {
                        message.error("上传失败：", error);
                    });
                }
            })
        }
    };
    const handleDeleteImage = () => {
        props.values.imgUrl = null;
        setUrl(null);
        props.form.setFieldsValue({ imgUrl: props.values.imgUrl });
      };
    const handleImageError = () => {
        setImageError(true);
    };
    return (
        <Modal
            title={props.values.id ? '编辑' : '新建'}
            width={640}
            open={props.createModalVisible}
            bodyStyle={{ padding: '32px 40px 1px 48px' }}
            footer={null}
            onCancel={() => {
                props.onCancel();
            }}
            maskClosable={false}
            destroyOnClose={true}
        >
            <Form
                labelCol={{ span: 4 }}
                layout="horizontal"
                preserve={false}
                form={props.form}
                onFinish={props.onFinish}>
                <Form.Item name="id" hidden={true}>
                    <Input />
                </Form.Item>
                <Form.Item name="goodsTypeId" label="工艺分类" rules={[{ required: true }]}>
                    <TreeSelect
                        allowClear
                        showSearch
                        disabled={props.values.id}
                        style={{ width: '100%' }}
                        dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                        treeData={treeData}
                        onChange={onChange}
                        filterTreeNode={filterOption}
                        value={goodsTypeIdvalue}
                        placeholder="请选择工艺分类"
                        treeDefaultExpandAll
                    />
                </Form.Item>
                <Form.Item name="name" label="商品名称" rules={[{ required: true }]}>
                    <Input />
                </Form.Item>
                <Form.Item name="goodsUintId" label="商品单位" rules={[{ required: true }]}>
                    <Select
                        style={{ width: '100%' }}
                        placeholder="请选择单位"
                        showSearch
                        allowClear
                        options={goodsUnit}
                        optionFilterProp="children" filterOption={(input, option) => (option?.label ?? '').includes(input)}
                        filterSort={(optionA, optionB) =>
                            (optionA?.label ?? '').toLowerCase().localeCompare((optionB?.label ?? '').toLowerCase())
                        }
                        dropdownRender={(menu) => (
                            <>
                                {menu}
                                <Divider style={{ margin: '8px 0' }} />
                                <Space style={{ padding: '0 8px 4px' }}>
                                    <Input
                                        placeholder="请输入单位"
                                        ref={inputRef}
                                        value={unitname}
                                        onChange={onNameChange}
                                        onKeyDown={(e) => e.stopPropagation()}
                                    />
                                    <Button type="text" icon={<PlusOutlined />} onClick={addItem}>
                                        新增
                                    </Button>
                                </Space>
                            </>
                        )}
                    />
                </Form.Item>
                <Form.Item name="price" label="商品价格">
                    <InputNumber style={{ width: '100%' }} placeholder="价格" min={0} />
                </Form.Item>
                <Form.Item name="isWeigh" label="是否称重" valuePropName="checked" >
                    <Switch checkedChildren="是" unCheckedChildren="否" defaultChecked={false} />
                </Form.Item>
                <Form.Item name="descritption" label="备注">
                    <TextArea rows={4} />
                </Form.Item>
                <Form.Item name="imgUrl" hidden={true}  >
                    <Input />
                </Form.Item>
                <Form.Item name="imgUrl1" label="商品图片">
                    <Upload {...uploadProp} showUploadList={false}>
                        <div
                            style={{
                                position: 'relative',
                                display: 'inline-block',
                                cursor: 'pointer',
                            }}
                            onMouseEnter={() => setHovered(true)}
                            onMouseLeave={() => setHovered(false)}
                        >
                            {!imageError && url ? (
                                <>
                                    <img
                                        src={url}
                                        alt=""
                                        style={{
                                            maxWidth: '100%',
                                            maxHeight: '150px',
                                            height: 'auto',
                                            borderRadius: '4px',
                                            transition: 'opacity 0.3s ease',
                                            opacity: hovered ? 0.5 : 1,
                                            backgroundColor: hovered ? 'rgba(0, 0, 0, 0.5)' : 'transparent',
                                        }}
                                        onError={handleImageError}
                                    />
                                    {hovered && (
                                        <Button
                                            type="link"
                                            danger
                                            onClick={(event) => {
                                                event.stopPropagation();
                                                handleDeleteImage();
                                              }}
                                            icon={<DeleteOutlined />}
                                            style={{
                                                position: 'absolute',
                                                top: '50%',
                                                left: '50%',
                                                transform: 'translate(-50%, -50%)',
                                            }}
                                        />
                                    )}
                                </>
                            ) : (
                                <Button icon={<UploadOutlined />}>上传</Button>
                            )}
                        </div>
                    </Upload>
                </Form.Item>
                <Form.Item>
                    <Button htmlType="button" style={{ float: 'right', left: 10 }} onClick={props.onCancel} >
                        取消
                    </Button>
                    <Button disabled={!props.codeList.includes('GoodInfoUp')} type="primary" htmlType="submit" style={{ float: 'right' }} >
                        保存
                    </Button>
                </Form.Item>
            </Form>
        </Modal>
    );
};

export default CreateForm;
