import React, { useState, useEffect, useRef } from 'react';
import { PlusOutlined } from '@ant-design/icons';
import { Modal, Form, Input, Button, Select, Radio, Divider, Space, message } from 'antd';
import {
  GetDeviceVesion,
  AddDeviceType
} from '../services';
const CreateForm = (props) => {
  const [deviceTypename, setdeviceTypename] = useState("");
  const [options, setoptions] = useState([]);
  const [stopoptions, setstopoptions] = useState([]);
  const [vesionoptions, setvesionoptions] = useState([]);
  const inputRef = useRef(null);
  useEffect(() => {
    if (Object.keys(props.values).length > 0) {
      var vesiondata = props.deviceVersions.map((item) => {
        return { value: item.id, label: item.vesion }
      })
    }
    setvesionoptions(vesiondata);
    var optdata = props.dicData.map((item) => {
      return { value: item.id, label: item.label }
    })
    setoptions(optdata);
    var stopData = props.StopData?.map((item) => {
      return { value: item.id, label: item.name }
    })
    setstopoptions(stopData)
  }, [props])
  const handleChange = (value) => {
    GetDeviceVesion(value).then((res) => {
      var vesiondata = res.data.map((item) => ({
        value: item.id, label: item.vesion
      }))
      setvesionoptions(vesiondata);
    })
  }
  const onNameChange = (event) => {
    setdeviceTypename(event.target.value);
  }
  const addItem = (e) => {
    e.preventDefault();
    if (deviceTypename.length == 0) {
      message.error("请输入名称");
    } else {
      var parm = { name: deviceTypename }
      AddDeviceType(parm).then((r) => {
        if (r.succeeded) {
          message.success('添加成功');
          props.initDeviceType()
          setdeviceTypename('');
        } else {
          message.error(r.errors);
        }
      })
    }
  }
  return (
    <Modal
      title={props.values.id ? '编辑' : '新建'}
      width={640}
      open={props.createModalVisible}
      maskClosable={false}
      bodyStyle={{ padding: '32px 40px 48px' }}
      footer={null}
      onCancel={() => {
        props.onCancel();
      }}
      destroyOnClose={true}
    >
      <Form
        layout="Horizontal"
        labelCol={{ span: 4 }}
        preserve={false}
        initialValues={props.values}
        onFinish={props.onFinish}
      >
        <Form.Item name="id" hidden={true}>
          <Input />
        </Form.Item>
        <Form.Item label={'选择场景'} name="stopId" rules={[{ required: true }]}>
          <Select allowClear showSearch optionFilterProp="children" filterOption={(input, option) => (option?.label ?? '').includes(input)}
            filterSort={(optionA, optionB) =>
              (optionA?.label ?? '').toLowerCase().localeCompare((optionB?.label ?? '').toLowerCase())} options={stopoptions} />


        </Form.Item>
        <Form.Item label={'产品'} name="productId" rules={[{ required: true }]}>
          <Select onChange={handleChange} allowClear showSearch optionFilterProp="children" filterOption={(input, option) => (option?.label ?? '').includes(input)}
            filterSort={(optionA, optionB) =>
              (optionA?.label ?? '').toLowerCase().localeCompare((optionB?.label ?? '').toLowerCase())
            } options={options} />
        </Form.Item>

        <Form.Item label={'产品版本'} name="productVersionId" rules={[{ required: true }]}>
          <Select allowClear showSearch optionFilterProp="children" filterOption={(input, option) => (option?.label ?? '').includes(input)}
            filterSort={(optionA, optionB) => (optionA?.label ?? '').toLowerCase().localeCompare((optionB?.label ?? '').toLowerCase())} options={vesionoptions} />
        </Form.Item>
        <Form.Item label={'设备名称'} name="deviceName" rules={[{ required: true, max: 50 }]}>
          <Input />
        </Form.Item>
        <Form.Item label={'设备标签'} name="deviceTypeId" rules={[{ required: false }]}>
          <Select
            style={{ width: '100%' }}
            placeholder="请选设备标签"
            options={props.storeType}
            allowClear showSearch
            optionFilterProp="children" filterOption={(input, option) => (option?.label ?? '').includes(input)}
            filterSort={(optionA, optionB) =>
              (optionA?.label ?? '').toLowerCase().localeCompare((optionB?.label ?? '').toLowerCase())
            }
            dropdownRender={(menu) => (
              <>
                {menu}
                <Divider style={{ margin: '8px 0' }} />
                <Space style={{ padding: '0 8px 4px' }}>
                  <Input
                    placeholder="请输入设备标签"
                    ref={inputRef}
                    value={deviceTypename}
                    onChange={onNameChange}
                    onKeyDown={(e) => e.stopPropagation()}
                  />
                  <Button type="text" icon={<PlusOutlined />} onClick={addItem}>
                    新增
                  </Button>
                </Space>
              </>
            )}
          />
        </Form.Item>
        <Form.Item label={'地址'} name="address" rules={[{ max: 50 }]}>
          <Input />
        </Form.Item>
        <Form.Item>
          <Button htmlType="button" style={{ float: 'right' }} onClick={props.onCancel} >
            取消
          </Button>
          <Button disabled={!props.codeList.includes('DeviceUp')} type="primary" htmlType="submit" style={{ float: 'right', marginRight: 10 }} >
            保存
          </Button>
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default CreateForm;
