import React, { useRef, useState, useEffect } from 'react';
import { Modal, Form, Input, Button, Select, Upload, InputNumber, message } from 'antd';
import { PlusOutlined, UploadOutlined, DeleteOutlined } from '@ant-design/icons';
import { GetAliyunRequestURL } from '../services';
const CreateForm = (props) => {
  const [modalVisible, setModalVisible] = useState(false);
  const [modalContent, setModalContent] = useState('');
  const [url, setUrl] = useState(null);
  const [hovered, setHovered] = useState(false);
  const [imageError, setImageError] = useState(false);
  const uploadProp = {
    customRequest({
      file,
    }) {
      GetAliyunRequestURL({ directory: "hkerp/test/deviceVesion", buildUniqueDirectory: false }).then((res) => {
        if (res.success_Action_Status == 200) {
          var formData = new FormData(); //注意formData里append添加的键的大小写
          formData.append("name", file.name); //文件名
          formData.append("key", res.key); //存储在oss的文件路径
          formData.append("ossAccessKeyId", res.ossAccessKeyId); //accessKeyId
          formData.append("policy", res.policy); //policy
          formData.append("signature", res.signature); //签名 //如果是base64文件，那么直接把base64字符串转成blob对象进行上传就可以了
          formData.append("file", file);
          formData.append("success_Action_Status", 200); //成功后返回的操作码
          formData.append("host", res.host);
          fetch(res.host, {
            method: "POST",
            body: formData,
          }).then((response) => {
            if (response.ok) {
              setUrl(`${res.host}/${res.key.replace("${filename}", file.name)}`)
              setImageError(false)
            }
          }).catch((error) => {
            message.error("上传失败：", error);
          });
        }
      })
    }
  };

  useEffect(() => {
    props.form.setFieldsValue(props.values);
    setUrl(props.values.productUrl);
  }, [props.values]);

  const handleCloseModal = () => {
    // 清空模态框内容
    setModalContent('');
    // 关闭模态框
    setModalVisible(false);
    props.onCancel();
  };
  const handleDeleteImage = () => {
    props.values.productUrl = null;
    setUrl(null);
    props.form.setFieldsValue({ productUrl: props.values.productUrl });
  };
  const handleImageError = () => {
      setImageError(true);
  };
  return (
    <Modal
      title={props.values.id ? '编辑' : '新建'}
      width={640}
      visible={props.createModalVisible}
      bodyStyle={{ padding: '32px 40px 48px' }}
      footer={null}
      onCancel={handleCloseModal}
      maskClosable={false}
      destroyOnClose={true}
    >
      <Form
        layout="vertical"
        preserve={false}
        form={props.form}
        onFinish={props.onFinish} >
        <Form.Item name="id" hidden={true}>
          <Input />
        </Form.Item>
        <Form.Item label={"所属产品"} name="productId" rules={[{ required: true, max: 50 }]} >
          <Select>
            {props.dicData.map((item, index) => {
              return (
                <Select.Option index={index} value={item.id} key={item.id}>
                  {item.label}
                </Select.Option>
              );
            })}
          </Select>
        </Form.Item>
        <Form.Item label={"版本号"} name="vesion" rules={[{ required: true, max: 50 }]} >
          <Input />
        </Form.Item>
        <Form.Item label={"仓位数量"} name="productNumber" rules={[{ required: true, }]} >
          <InputNumber min={1} />
        </Form.Item>
        <Form.Item label={"备注"} name="remark">
          <Input />
        </Form.Item>
        <Form.Item name="productUrl" hidden={true}>
          <Input />
        </Form.Item>
        <Form.Item name="productUrl1" label={"图片"}  >
          <Upload {...uploadProp} showUploadList={false}>
            <div
              style={{
                position: 'relative',
                display: 'inline-block',
                cursor: 'pointer',
              }}
              onMouseEnter={() => setHovered(true)}
              onMouseLeave={() => setHovered(false)}
            >
              {!imageError && url ? (
                <>
                  <img
                    src={url}
                    alt=""
                    style={{
                      maxWidth: '100%',
                      maxHeight: '150px',
                      height: 'auto',
                      borderRadius: '4px',
                      transition: 'opacity 0.3s ease',
                      opacity: hovered ? 0.5 : 1,
                      backgroundColor: hovered ? 'rgba(0, 0, 0, 0.5)' : 'transparent',
                    }}
                    onError={handleImageError}
                  />
                  {hovered && (
                    <Button
                      type="link"
                      danger
                      onClick={(event) => {
                        event.stopPropagation();
                        handleDeleteImage();
                      }}
                      icon={<DeleteOutlined />}
                      style={{
                        position: 'absolute',
                        top: '50%',
                        left: '50%',
                        transform: 'translate(-50%, -50%)',
                      }}
                    />
                  )}
                </>
              ) : (
                <Button icon={<UploadOutlined />}>上传</Button>
              )}
            </div>
          </Upload>
        </Form.Item>
        <Form.Item>
          {props.values.isUse ? (<span style={{ color: '#FA541C' }}>当前版本已有设备使用，无法修改！</span>) : (<Button type="primary" htmlType="submit">
            保存
          </Button>)}
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default CreateForm;
