import React, {useState,useEffect } from 'react';
import { Modal, Form, Input, Select,Image, InputNumber, Button } from 'antd';
import {
  EditableProTable
} from '@ant-design/pro-table';
const CreateForm = (props) => {
  const [form] = Form.useForm();
  const [dataSource, setDataSource] = useState([]);
  const [editableKeys, setEditableRowKeys] = useState([]);
  const [options,setoptions]=useState([]);
  const [ProductUrl,setProductUrl]=useState('');
  useEffect(() => {
    if(props.values.id){
      form.setFieldsValue({
        id: props.values.id,
        templateName:props.values.templateName,
        sort:props.values.sort,
        deviceId:props.values.deviceId,
      });
      var data=props.values.warehousePostion.map(x=>{
        return {id: x.id,code:x.code,batchingId:x.batchingId}
      })
      setEditableRowKeys(data.map((item) => item.id))
      setDataSource(data)
    }else{
      setDataSource([])
    }
    var optdata=props.devicedata?.map((item, index) => {
      return {value:item.id,label:item.name}
    })
    setoptions(optdata);
    setProductUrl(props.values.productUrl)
  },[props])
  const columns=[
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key'
    },
    {
        title: '仓位编码',
        dataIndex: 'code',
      },
    {
        title: '物料',
        dataIndex: 'batchingId',
        valueType: 'select',
        fieldProps: {
          showSearch:true,
          options: props.matedata.map((item, index) => {return {label:item.name,value:item.id}})
        },
        width: '45%',
      },
  ]
  const handleChange=(value)=>{
    var device=props.devicedata.find(x=>x.id==value);
    if(device){
      var ary=[]
      for (let index = 0; index < device.productNumber; index++) {
        ary.push({id: index,code:'LC'+(String(index+1).padStart(4, '0')),batchingId:null})
      }
      setEditableRowKeys(ary.map((item) => item.id))
      setDataSource(ary);
      setProductUrl(device.productUrl)
    }
  }
  const headleOk = () => {
    form.validateFields().then((data) => {
      var check = true
      if (dataSource.length == 0) {
        check = false;
        message.error("请选择物料")
      }
      if (check) {
        data.warehousePostionData = dataSource
        props.onFinish(data)
      }
    })
  }
  return (
    <Modal
      title={props.values.id ? '编辑' : '新建'}
      width={640}
      open={props.createModalVisible}
      bodyStyle={{ padding: '32px 40px 48px' }}
      footer={null}
      onCancel={() => {
        props.onCancel();
        setDataSource([])
        setEditableRowKeys([])
        setProductUrl('')
      }}
      maskClosable={false}
      destroyOnClose={true}
    >
      <Form
        layout="vertical"
        preserve={false}
        form={form}
        >
        <Form.Item name="id" hidden={true}>
          <Input />
        </Form.Item>
        <Form.Item label={"模板名称"} name="templateName"  rules={[{ required: true,max:50}]} >
          <Input />
        </Form.Item>
        <Form.Item label={"选择设备"} name="deviceId"  rules={[{ required: true,max:50}]} >
            <Select style={{width: '100%'}} allowClear showSearch
            optionFilterProp="children"  filterOption={(input, option) => (option?.label ?? '').includes(input)}
            filterSort={(optionA, optionB) =>
              (optionA?.label ?? '').toLowerCase().localeCompare((optionB?.label ?? '').toLowerCase()) 
            }
            onChange={handleChange} options={options}/>
        </Form.Item>
        <Form.Item label={"序号"} name="sort">
            <InputNumber style={{width: '100%'}}/>
        </Form.Item>
        <Form.Item label={"设备仓位图"} name="productUrl"  rules={[{ required: false,max:50}]} >
        <Image
          width={120}
          src={ProductUrl}
        />
        </Form.Item>
      </Form>
      <EditableProTable
       headerTitle={ <span><span style={{color:'red',marginRight: 3}}>*</span>仓位详情</span>}
        columns={columns}
        rowKey="id"
        value={dataSource}
        onChange={setDataSource}
        recordCreatorProps={false}
        editable={{
          type: 'multiple',
          editableKeys,
          actionRender: (row, config, defaultDoms) => {
            return [];
          },
          onValuesChange: (record, recordList) => {
            setDataSource(recordList);
          },
          onDelete:async (key, row) =>{
          },
          onChange: setEditableRowKeys,
        }}/>
      <Form.Item>
        <Button htmlType="button" style={{ float: 'right' }} onClick={props.onCancel} >
          取消
        </Button>
        <Button disabled={!props.codeList.includes('DeviceWareUp')} type="primary" htmlType="submit" style={{ float: 'right', marginRight: 10 }} onClick={headleOk}>
          保存
        </Button>
      </Form.Item>
    </Modal>
  );
};

export default CreateForm;
