
import { Button, message, Popconfirm } from 'antd';
import React, { useState, useRef,useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import { PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import { GetWarehousetemplatePage, WarehousetemplateAdd, WarehousetemplateDel, WarehousetemplateUpdate,Getdevice,GetBatching } from "./services";
import publicApi from '@/services/api';

const key = 'message';
const GoodsTypeManage = () => {
  const [createModalVisible, handleModalVisible] = useState(false);
  const actionRef = useRef();
  const [currentRow, setCurrentRow] = useState();
  const [selectedRowsState, setSelectedRows] = useState([]);
  const [devicedata, setdevicedata] = useState([]);
  const [devicevalueEnumdata, setdevicevalueEnumdata] = useState([]);
  const [matedata, setMatedata] = useState([]);
  const [codeList, setCodeList] = useState([]);
  useEffect(() => {
    publicApi.getRoleBasicMenu().then((r) => {
      if (r.data) {
        setCodeList(r.data)
      }
    })
    Getdevice().then((r)=>{
      let list = {};
      r.data.forEach((item) => {
        list[item.id] = { text: item.name };
      })
      setdevicevalueEnumdata(list)
        setdevicedata(r.data)
    })
   
    GetBatching().then((r) => {
        setMatedata(r.data);
    });
    
  },[])
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key'
    },
    {
      title: '模板名称',
      dataIndex: 'templateName',
      valueType: 'textarea',
    },
    {
      title: '设备名称',
      dataIndex: 'deviceName',
      valueEnum:devicevalueEnumdata
    },
    {
      title: '仓位数',
      dataIndex: 'productNumber',
      valueType: 'textarea',
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 450,
      render: (_, record) => [
        <a
          key="config"
          onClick={() => {
            handleModalVisible(true);
            setCurrentRow(record);
          }} > 更新</a>,
          codeList.includes('DeviceWareDel') && (
              <Popconfirm
              type="primary"
              key="primary"
              title="确认删除吗？"
              okText="是"
              cancelText="否"
              onConfirm={() => {
                WarehousetemplateDel([record.id]).then((r) => {
                  if (r.data) {
                    message.success('删除成功');
                    actionRef.current.reload();
                  } else {
                    message.error(r.errors);
                  }
                });
              }}
              onCancel={() => { }}
            >
              <a href="#">删除</a>
            </Popconfirm>),
      ],
    },
  ];
  //添加
  const handleAdd = async (fields) => {
    try {
      await WarehousetemplateAdd(JSON.stringify(fields)).then((r) => {
        if (r.succeeded) {
          message.success('添加成功');
          actionRef.current.reload();
          handleModalVisible(false);
        } else {
          message.error(r.errors);
        }
      });
    } catch (error) {
      message.error('添加失败请重试！');
      
    }
  };
  
  
  //修改
  const handleUpdate = async (fields) => {
    try {
      message.loading('正在修改', key);
      message.destroy(key);
      await WarehousetemplateUpdate(JSON.stringify(fields)).then((r) => {
        message.destroy(key);
        if (r.succeeded) {
          message.success('修改成功',);
          actionRef.current.reload();
          handleModalVisible(false);
        } else {
          message.error(r.errors);
        }
      });
    } catch (error) {
      message.error('修改失败请重试！');
    }
  };
  
  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  //删除
  const handleRemove = async (selectedRows) => {
    let ids = [];
    selectedRows.forEach((item) => {
      ids.push(item.id);
    });
    await WarehousetemplateDel(ids).then((r) => {
      if (r.data) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error('删除失败请重试！');
      }
    });
    return true;
  };
  return (
    <PageContainer host header={{
      title: '',
      breadcrumb: {},
    }}>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          codeList.includes('DeviceWareAdd') && (
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setCurrentRow(undefined);
              handleModalVisible(true);
            }} >
            <PlusOutlined /> 新建
          </Button>),
          codeList.includes('DeviceWareDel') && (
          <BatchDeletion />),
        ]}
        request={async (params) => {
          var data = [];
          var total = 0;
          await GetWarehousetemplatePage(params).then((r) => {
            data = r.data.data;
            total = r.data.total;
          });
          return {
            data: data,
            success: true,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />
      <CreateForm
        onFinish={async (value) => {
          if (value.id) {
            handleUpdate(value);
          } else {
            handleAdd(value);
          }
        }}
        onCancel={() => {
          handleModalVisible(false);
          setCurrentRow(undefined);
        }}
        codeList={codeList}
        createModalVisible={createModalVisible}
        values={currentRow || {}}
        devicedata={devicedata}
        matedata={matedata}
      />
    </PageContainer>
  );
};

export default GoodsTypeManage;
