import { CopyOutlined } from '@ant-design/icons';
import { Button, Select, Modal, Form, message, Drawer, Collapse } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from "@ant-design/pro-layout";
import ProTable from "@ant-design/pro-table";
import ProDescriptions from '@ant-design/pro-descriptions';
import Field from '@ant-design/pro-field';
import api from './service';
import moment from 'moment';
import publicApi from '@/services/api';
const { Panel } = Collapse;

const orderinfo = () => {
  const actionRef = useRef();
  const [storeDeviceOpen, setStoreDeviceOpen] = useState(false);
  const [orderDetailOpen, setOrderDetailOpen] = useState(false);
  const [showDetail, setShowDetail] = useState(false);
  const [currentRow, setCurrentRow] = useState();
  const [storeList, setStoreList] = useState();
  const [deviceList, setDeviceList] = useState();
  const [storeId, setStoreId] = useState();
  const [deviceId, setDeviceId] = useState();
  const [storeSelectList, setStoreSelectList] = useState();
  const [deviceSelectList, setDeviceSelectList] = useState();
  const [orderInfo, setOrderInfo] = useState([]);
  const [codeList, setCodeList] = useState([]);
  const orderStatusList = [
    { value: 1, label: '未完成' },
    { value: 2, label: '已完成' },
    { value: 3, label: '异常' },
    { value: 4, label: '取消' },
  ]
  const goodStatusList = [
    { value: 0, label: '等待' },
    { value: 1, label: '完成' },
    { value: 2, label: '执行中' },
    { value: 3, label: '异常' },
    { value: 4, label: '取消' },
  ]
  const pushStatusList = [
    { value: 0, label: '下发中' },
    { value: 1, label: '成功未回调' },
    { value: 2, label: '成功已回调' },
    { value: 3, label: '失败' },
    { value: 99, label: '设备上传' }
  ]
  const [timeRange, setTimeRange] = useState([moment().startOf('day'), moment().endOf('day')]); 
  useEffect(() => {
    publicApi.getRoleBasicMenu().then((r) => {
      if (r.data) {
        setCodeList(r.data)
      }
    })
    api.getStoreDeviceList().then((r) => {
      if (r.data) {
        setStoreList(r.data)
      }
    })
    api.getOrderSelectList().then((r) => {
      if (r.data) {
        setStoreSelectList(r.data.storeList)
        setDeviceSelectList(r.data.deviceList)
      }
    })
  }, [])
  const handleStoreChange = (value) => {
    setStoreId(value)
    var data = storeList.find(t => t.storeId == value)
    setDeviceList(data.deviceList)
  }
  const handleDeviceChange = (value) => {
    setDeviceId(value)
  }
  const detailColumns = [
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key'
    },
    {
      title: '商品名称',
      dataIndex: 'goodsName',
      ellipsis: true,
      width: 250,
      render: (_, record) => {
        return <span>{`${record.goodsName}【${record.attributeName}】`}</span>;
      },
    },
    {
      title: '商品价格(￥)',
      dataIndex: 'goodsPrice',
      hideInSearch: true,
    },
    {
      title: '制作状态',
      dataIndex: 'status',
      hideInSearch: true,
      render: (_, record) => {
        return <span>{goodStatusList.find(status => status.value === record.status)?.label}</span>;
      },
    },
    {
      title: '更新时间',
      dataIndex: 'updateTime',
      width: 200,
      hideInSearch: true,
    },
  ];
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key'
    },
    {
      title: '单号',
      dataIndex: 'code',
      ellipsis: true,
    },
    {
      title: '编号',
      dataIndex: 'number',
      ellipsis: true,
      render: (_, record) => {
        return <span>#{record.number}</span>;
      },
    },
    {
      title: '订单状态',
      dataIndex: 'status',
      hideInSearch: true,
      valueType: 'select',
      fieldProps: {
        options: orderStatusList,
      },
    },
    {
      title: '下发状态',
      dataIndex: 'pushStatus',
      valueType: 'select',
      hideInSearch: true,
      fieldProps: {
        options: pushStatusList,
      },
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'dateTimeRange',
      render: (_, record) => {
        return <span>{record.createAt}</span>;
      },
      fieldProps: {
        style: { width: 330 },
        value: timeRange,
        allowClear: false,
        onChange: (dates) => {
          setTimeRange(dates);
        }
      }
    },
    {
      title: '门店',
      dataIndex: 'storeName',
      valueType: 'select',
      fieldProps: {
        options: storeSelectList,
      },
    },
    {
      title: '设备',
      dataIndex: 'deviceName',
      valueType: 'select',
      fieldProps: {
        options: deviceSelectList,
      },
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 250,
      render: (_, record) => [
        codeList.includes('OrderInfoAdd') && (
        <Button
          type='link'
          style={{ marginRight: -16, marginLeft: -16 }}
          disabled={record.pushStatus === 0 || record.pushStatus === 2 || record.pushStatus === 99}
          onClick={() => {
            api.placeOrderAgain(record.id).then((r) => {
              if (r.data) {
                message.success("再次下单成功")
              } else {
                message.error(r.errors)
              }
              actionRef.current.reload();
            })
          }}
        >
          再次下发
        </Button>),
        codeList.includes('OrderInfoDetail') && (
        <Button
          type='link'
          style={{ marginRight: -16, marginLeft: -16 }}
          onClick={() => {
            setOrderInfo(record)
            setOrderDetailOpen(true)
          }}
        >
          查看订单
        </Button>),
        codeList.includes('OrderInfoView') && (
        <Button
          type='link'
          style={{ marginRight: -16, marginLeft: -16 }}
          disabled={record.pushStatus === 99}
          onClick={() => {
            setCurrentRow(record.record)
            setShowDetail(true)
          }}
        >
          下发详情
        </Button>),
      ],
    },
  ];
  return (
    <PageContainer
      host
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <ProTable
        headerTitle="订单列表"
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          codeList.includes('OrderInfoAdd') && (
          <Button
            type="primary"
            onClick={() => { setStoreDeviceOpen(true) }}
          >
            下单 {'>'}
          </Button>),
        ]}
        request={async (params) => {
          var orderInfoData = [];
          var total = 0;
          const [startTime, endTime] = timeRange;
          params.startTime = startTime.format('YYYY-MM-DD HH:mm:ss');
          params.endTime = endTime.format('YYYY-MM-DD HH:mm:ss');
          await api.getOrderInfoPage(params).then((r) => {
            orderInfoData = r.data.data;
            total = r.data.total;
          });
          return {
            data: orderInfoData,
            success: true,
            total: total,
          };
        }}
        columns={columns}
      />

      <Modal
        title='选择店铺和设备去下单'
        open={storeDeviceOpen}
        width={500}
        bodyStyle={{ padding: '32px 40px 1px 48px' }}
        onOk={() => {
          const token = sessionStorage.getItem('token');
          const userid = sessionStorage.getItem('userid');
          const tokenEncoded = encodeURIComponent(token);
          const useridEncoded = encodeURIComponent(userid);
          const storesId = storeId;
          const autoKey = deviceId;
          window.open(`orderview?tokenEncoded=${tokenEncoded}&useridEncoded=${useridEncoded}&storeId=${storesId}&autoKey=${autoKey}`, "_blank");
          setStoreDeviceOpen(false);
          setStoreId();
          setDeviceId();
        }}
        okText="确认"
        onCancel={() => { setStoreDeviceOpen(false) }}
        cancelText="取消"
        maskClosable={false}
        destroyOnClose
      >
        <Form
          layout="horizontal"
          preserve={false}
        >
          <Form.Item name="storeId" label="场景" rules={[{ required: true }]}>
            <Select
              showSearch
              optionFilterProp="label"
              onChange={handleStoreChange}
              options={storeList?.length > 0 ? storeList.map((r) => ({ value: r.storeId, label: r.name })) : ""}
              placeholder="请选择场景"
            />
          </Form.Item>
          <Form.Item name="deviceId" label="设备" rules={[{ required: true }]}>
            <Select
              showSearch
              optionFilterProp="label"
              onChange={handleDeviceChange}
              options={deviceList?.length > 0 ? deviceList.map((r) => ({ value: r.deviceId, label: r.name })) : ""}
              placeholder="请选择设备"
            />
          </Form.Item>
        </Form>
      </Modal>

      <Modal
        title='订单详情'
        open={orderDetailOpen}
        width={800}
        bodyStyle={{ padding: '32px 40px 1px 48px' }}
        footer={false}
        onCancel={() => { setOrderDetailOpen(false) }}
      >
        <h3>单号：{orderInfo.code}</h3>
        <h3>订单创建时间：{orderInfo.createAt}</h3>
        <h3>更新时间：{orderInfo.updateTime}</h3>
        <h3>订单状态：{orderStatusList.find(status => status.value === orderInfo.status)?.label}</h3>
        <h3>场景：{orderInfo.storeName}</h3>
        <h3>设备：{orderInfo.deviceName}</h3>
        <ProTable
          rowKey="id"
          width={600}
          columns={detailColumns}
          dataSource={orderInfo.goodsList}
          options={false}
          search={false}
          style={{ marginTop: 10 }}
          pagination={{ defaultPageSize: 5 }}
        />
      </Modal>

      <Drawer
        width={600}
        open={showDetail}
        onClose={() => {
          setCurrentRow(undefined);
          setShowDetail(false);
        }}
        closable={false}
      >
        {currentRow?.deviceName && (
          <ProDescriptions column={1}>
            <ProDescriptions.Item label="下发设备" valueType="text">
              {currentRow?.deviceName}
            </ProDescriptions.Item>
            <ProDescriptions.Item label="消息id" copyable valueType="text">
              {currentRow?.messageId}
            </ProDescriptions.Item>
            <ProDescriptions.Item>
              <Collapse defaultActiveKey={['1']} >
                <Panel header="下发详情" key="1">
                  <ProDescriptions column={1}>
                    <ProDescriptions.Item label="下发topic" copyable valueType="text">
                      {currentRow?.topic}
                    </ProDescriptions.Item>
                    <ProDescriptions.Item label="下发状态" valueType="text">
                      {currentRow?.description}
                    </ProDescriptions.Item>
                    <ProDescriptions.Item contentStyle={{ maxWidth: '85%' }} label="下发数据">
                      <a
                        onClick={() => {
                          let oInput = document.createElement('input');
                          oInput.value = currentRow.dataResore;
                          document.body.appendChild(oInput);
                          oInput.select(); // 选择对象
                          document.execCommand('Copy'); // 执行浏览器复制命令
                          message.success('复制成功');
                          oInput.remove();
                        }}
                      >
                        <CopyOutlined />
                        <div style={{ width: '444px', overflow: 'scroll', overflowX: 'auto' }}>
                          <Field text={currentRow?.dataResore} valueType="jsonCode" />
                        </div>
                      </a>
                    </ProDescriptions.Item>
                  </ProDescriptions>
                </Panel>
                <Panel header="回调详情" key="2">
                  <ProDescriptions column={1}>
                    <ProDescriptions.Item label="回调topic" copyable valueType="text">
                      {currentRow?.topicRely}
                    </ProDescriptions.Item>
                    <ProDescriptions.Item label="回调状态" valueType="text">
                      {currentRow?.descriptionRely}
                    </ProDescriptions.Item>
                    <ProDescriptions.Item contentStyle={{ maxWidth: '85%' }} label="回调数据">
                      <a
                        onClick={() => {
                          let oInput = document.createElement('input');
                          oInput.value = currentRow.dataResore;
                          document.body.appendChild(oInput);
                          oInput.select();
                          document.execCommand('Copy');
                          message.success('复制成功');
                          oInput.remove();
                        }}
                      >
                        <CopyOutlined />
                        <div style={{ width: '444px', overflow: 'scroll', overflowX: 'auto' }}>
                          <Field text={currentRow?.dataResoreRely} valueType="jsonCode" />
                        </div>
                      </a>
                    </ProDescriptions.Item>
                  </ProDescriptions>
                </Panel>
              </Collapse>
            </ProDescriptions.Item>
          </ProDescriptions>
        )}
      </Drawer>
    </PageContainer>
  )
}

export default orderinfo;