import { Modal, Form, Input, Button, TreeSelect } from 'antd';

const CreateForm = (props) => {

    return (
        <Modal
            title={props.values.id ? '编辑用户' : '新建用户'}
            width={640}
            open={props.modalVisible}
            maskClosable={false}
            bodyStyle={{ padding: '32px 40px 1px 48px' }}
            footer={null}
            onCancel={() => {
                props.onCancel();
            }}
            destroyOnClose
        >
            <Form
                preserve={false}
                layout="horizontal"
                labelCol={{
                    span: 6,
                }}
                initialValues={props.values}
                onFinish={props.onFinish}
            >
                <Form.Item name="id" hidden={true}>
                    <Input />
                </Form.Item>
                <Form.Item name="sysOrgId" label="所属组织" rules={[{ required: true }]}>
                    <TreeSelect
                        style={{ width: '100%' }}
                        dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                        treeData={props.treeDatas}
                        placeholder="请选择上级名称"
                        treeDefaultExpandAll
                    />
                </Form.Item>

                <Form.Item name="account" label="登录账户(手机号)"
                    tooltip="初始密码为:123456"
                    rules={[{
                        required: true, max: 255, pattern: /0?(13|14|15|18|17)[0-9]{9}$/,
                        message: '手机号格式不正确'
                    }]}>
                    <Input placeholder="请输入登录账户" disabled={props.values.id ? true : false} />
                </Form.Item>
                <Form.Item name="name" label="用户姓名" rules={[{ required: true, max: 255 }]}>
                    <Input placeholder="请输入用户姓名" />
                </Form.Item>
                <Form.Item>
                    <Button htmlType="button" style={{ float: 'right', left: 10 }} onClick={props.onCancel} >
                        取消
                    </Button>
                    <Button disabled={!props.codeList.includes('UserUp')} type="primary" htmlType="submit" style={{ float: 'right' }} >
                        保存
                    </Button>
                </Form.Item>
            </Form>
        </Modal>
    );
};

export default CreateForm;
