import { PlusOutlined,CopyOutlined } from '@ant-design/icons';
import { Button, message, Input, Drawer, Popconfirm,Typography,Collapse } from 'antd';
import React, { useState, useRef, useEffect} from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import ProDescriptions from '@ant-design/pro-descriptions';
import PushFrom from './components/PushFrom';
import Field from '@ant-design/pro-field';
import {
    GetDevicePushRecodePage,
    GetStop,
    DevicePushRecodeDelete,
    DevicePushRecodeUpdate
} from './services';



const goodspush = () => {
  /** 新建/更新窗口的弹窗 */
  const [createModalVisible, handleModalVisible] = useState(false);
  /** 分布更新窗口的弹窗 */
  const [showDetail, setShowDetail] = useState(false);
  const actionRef = useRef();
  const [currentRow, setCurrentRow] = useState();
  const [selectedRowsState, setSelectedRows] = useState([]);
  const [StopData, setStopData] = useState([]);
  const { Paragraph, Text } = Typography;
  const { Panel } = Collapse;
  /** 国际化修改 */
  useEffect(() => {
    GetStop().then((t)=>{
      setStopData(t.data)
    })
    
  }, []);
  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  /**
   * 批量删除
   *
   * @param selectedRows
   */
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await DevicePushRecodeDelete(selectedRows.map((row) => row.id)).then((r) => {
      if (r.succeeded) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key',
      render: (dom, entity) => {
        return (
          <a
            onClick={() => {
              setCurrentRow(entity);
              //setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
    },
    {
      title: '下发设备',
      dataIndex: 'deviceName',
      valueType: 'textarea',
      ellipsis: true,
    },

    {
      title: '下发状态',
      dataIndex: 'status',
      ellipsis: true,
      valueEnum: {
        0: {
          text: '下发中',
          status: 'Processing',
      },
        1: {
            text: '成功',
            status: 'Success',
        },
        2: {
          text: '失败',
          status: 'Error',
      },
      },
    },
    {
      title: '下发时间',
      dataIndex: 'createAt',
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <a
          key="config"
          onClick={() => {
            setShowDetail(true);
            setCurrentRow(record);
          }}
        >
          下发详情
        </a>,
         <a
         key="config"
         onClick={() => {
           DevicePushRecodeUpdate(record.id).then((r)=>{
             if(r.data){
               message.success('操作成功');
               actionRef.current.reload();
             }else{
               message.error('操作失败');
             }
           })
         }}
       >
         重发
         </a>,
        // <Popconfirm
        //   type="primary"
        //   key="primary"
        //   title="确认删除吗？"
        //   okText="是"
        //   cancelText="否"
        //   onConfirm={async () => {
        //     await DeleteGoodsType(record.id).then((r) => {
        //       if (r.succeeded) {
        //         message.success('删除成功');
        //         actionRef.current.reload();
        //       } else {
        //         message.error(r.errors);
        //       }
        //     });
        //   }}
        //   onCancel={() => {}}
        // >
        //   <a href="#">删除</a>
        // </Popconfirm>,
      ],
    },
  ];
const HandleOk= async(values)=>{
  handleModalVisible(!values);
  actionRef.current.reload();
}

  return (
    <PageContainer host header={{
      title: '',
      breadcrumb: {},
    }}>
      
      <ProTable
        headerTitle=""
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              handleModalVisible(true);
            }}
          >
            <PlusOutlined /> 下发数据
          </Button>,
          <BatchDeletion />
        ]}
        request={async (params) => {
          var goodsData = [];
          var total = 0;
          params.type=2
          await GetDevicePushRecodePage(params).then((r) => {
            goodsData = r.data.data;
            total = r.data.total;
          });
          return {
            data: goodsData,
            success: true,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />

      <PushFrom
        onFinish={async (value) => {
         
        }}
        onCancel={() => {
          handleModalVisible(false);
          setCurrentRow(undefined);
        }}
        createModalVisible={createModalVisible}
        HandleOk={HandleOk}
        values={currentRow || {}}
        StopData={StopData}
      />

      <Drawer
        width={600}
        visible={showDetail}
        onClose={() => {
          setCurrentRow(undefined);
          setShowDetail(false);
        }}
        closable={false}
      >
        {currentRow?.deviceName && (
           <ProDescriptions column={1}>
             <ProDescriptions.Item label="下发设备" valueType="text">
              {currentRow?.deviceName}
              </ProDescriptions.Item>
              <ProDescriptions.Item label="消息id" copyable valueType="text">
              {currentRow?.messageId}
              </ProDescriptions.Item>
              <ProDescriptions.Item>
           <Collapse  defaultActiveKey={['1']} >
            <Panel header="下发详情" key="1">
              <ProDescriptions column={1}>
             
              <ProDescriptions.Item label="下发topic" copyable valueType="text">
              {currentRow?.topic}
              </ProDescriptions.Item>
              <ProDescriptions.Item label="下发状态" valueType="text">
              {currentRow?.description}
              </ProDescriptions.Item>
              <ProDescriptions.Item contentStyle={{ maxWidth: '85%'}} label="下发数据">
              
              <a
              onClick={() => {
              let oInput = document.createElement('input');
              oInput.value = currentRow.dataResore;
              document.body.appendChild(oInput);
              oInput.select(); // 选择对象
              document.execCommand('Copy'); // 执行浏览器复制命令
              message.success('复制成功');
              oInput.remove();
            }}
            >
            <CopyOutlined />
      
            <div style={{ width:'444px', overflow: 'scroll', overflowX: 'auto' }}>
              <Field text={currentRow?.dataResore} valueType="jsonCode" />
            </div>
            </a>
            </ProDescriptions.Item>
              </ProDescriptions>
            </Panel>
            <Panel header="回调详情" key="2">
            <ProDescriptions column={1}>
            
              <ProDescriptions.Item label="回调topic" copyable valueType="text">
              {currentRow?.topicRely}
              </ProDescriptions.Item>
              
              <ProDescriptions.Item label="回调状态" valueType="text">
              {currentRow?.descriptionRely}
              </ProDescriptions.Item>
              <ProDescriptions.Item contentStyle={{ maxWidth: '85%'}} label="回调数据">
              
              <a
              onClick={() => {
              let oInput = document.createElement('input');
              oInput.value = currentRow.dataResore;
              document.body.appendChild(oInput);
              oInput.select(); // 选择对象
              document.execCommand('Copy'); // 执行浏览器复制命令
              message.success('复制成功');
              oInput.remove();
            }}
            >
            <CopyOutlined />
      
            <div style={{width:'444px',  overflow: 'scroll', overflowX: 'auto' }}>
              <Field text={currentRow?.dataResoreRely} valueType="jsonCode" />
            </div>
            </a>
            </ProDescriptions.Item>
              </ProDescriptions>
            </Panel>
          </Collapse>
          </ProDescriptions.Item>
          </ProDescriptions>
        )}
      </Drawer>
    </PageContainer>
  );
};

export default goodspush;
