import { PageContainer } from "@ant-design/pro-layout";
import ProTable from "@ant-design/pro-table";
import api from './service';
import moment from 'moment';

const devicelog = () => {

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '文件名称',
      dataIndex: 'fileName',
      ellipsis: true,
    },
    {
      title: '加盟商名称',
      dataIndex: 'companyName',
      hideInSearch: true,
      ellipsis: true,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'dateTimeRange',
      render: (_, record) => {
        return <span>{record.createAt}</span>;
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 350,
      render: (_, record) => [
        <a
          key="config"
          href={record.fileUrl}
          download
        >
          下载
        </a>
      ]
    }
  ]
  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <ProTable
        headerTitle="日志列表"
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 'auto',
          span: '1',
          collapseRender: false,
          defaultParams: {
            createAt: [moment().startOf('month'), moment().endOf('month')],
          },
        }}
        request={async (params) => {
          let logData = [];
          var total = 0;
          params.startTime = params.createAt != undefined ? params.createAt[0] : null;
          params.endTime = params.createAt != undefined ? params.createAt[1] : null;
          await api.getDeviceLogPage(params).then((r) => {
            logData = r.data.data;
            total = r.data.total;
          });
          return {
            data: logData,
            total: total
          };
        }}
        columns={columns}
      />
    </PageContainer>
  )
}

export default devicelog;